﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using PdfSharp;
using PdfSharp.Pdf;
using ThinkGeo.MapSuite.Core;
using System.Drawing;
using System.Diagnostics;

namespace WebApplication1
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                Map1.CurrentExtent = new RectangleShape(-180.0, 83.0, 180.0, -90.0);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                EcwRasterLayer worldImageLayer = new EcwRasterLayer(MapPath(@"~\SampleData\World.ecw"));

                ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(MapPath(@"~/SampleData\Countries02.shp"));
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.StartCap = DrawingLineCap.Round;
                worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.EndCap = DrawingLineCap.Round;
                worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Map1.StaticOverlay.Layers.Add(worldImageLayer);
                Map1.StaticOverlay.Layers.Add(worldLayer);
            }
        }

        public void ToPdf(object sender, EventArgs e)
        {
            string pageSize = this.PageSise.SelectedValue;

            PdfDocument document = new PdfDocument();
            PdfPage page = document.AddPage();
            page.Size = GetPageSize(pageSize);

            page.Orientation = PageOrientation.Landscape;

            StretchingPdfGeoCanvas pdfGeoCanvas = new StretchingPdfGeoCanvas();

            // This allows you to control the area in which you want the
            // map to draw in.

            int resultWidth = (int)page.Width.Value;
            int resultHeight = (int)page.Height.Value;

            pdfGeoCanvas.DrawingArea = new Rectangle(0, 0, resultWidth, resultHeight);

            double resolution = Math.Max(Map1.CurrentExtent.Width / Map1.Width.Value, Map1.CurrentExtent.Height / Map1.Height.Value);
            RectangleShape newDrawingExtent = new RectangleShape(Map1.CurrentExtent.UpperLeftPoint.X, Map1.CurrentExtent.UpperLeftPoint.Y, Map1.CurrentExtent.UpperLeftPoint.X + Map1.Width.Value * resolution, Map1.CurrentExtent.UpperLeftPoint.Y - Map1.Height.Value * resolution);

            Collection<SimpleCandidate> labelsInLayers = new Collection<SimpleCandidate>();
            foreach (Layer layer in Map1.StaticOverlay.Layers)
            {
                pdfGeoCanvas.BeginDrawing(page, newDrawingExtent, GeographyUnit.DecimalDegree);
                layer.Open();
                layer.Draw(pdfGeoCanvas, labelsInLayers);
                layer.Close();
                pdfGeoCanvas.EndDrawing();
            }

            string filename = "MapSuite PDF Map.pdf";
            document.Save(filename);
            Process.Start(filename);
        }

        private PageSize GetPageSize(string pageSize)
        {
            switch (pageSize)
            {
                case "A1":
                    return PageSize.A1;
                case "A2":
                    return PageSize.A2;
                case "A4":
                    return PageSize.A4;
                default:
                    return PageSize.A4;
            }
        }
    }
}
